<ul id="navbar-main-elements" class="navbar-nav">
  <li class="nav-item">
    <a class="reference internal nav-link" href="{{ mpl_path('plot_types/index') }}">Plot types</a>
  </li>
  <li class="nav-item">
    <a class="reference internal nav-link" href="{{ mpl_path('users/index') }}">User guide</a>
  </li>
  <li class="nav-item">
    <a class="reference internal nav-link" href="{{ mpl_path('tutorials/index') }}">Tutorials</a>
  </li>
  <li class="nav-item">
    <a class="reference internal nav-link" href="{{ mpl_path('gallery/index') }}">Examples</a>
  </li>
  <li class="nav-item">
    <a class="reference internal nav-link" href="{{ mpl_path('api/index') }}">Reference</a>
  </li>
  <li class="nav-item">
    <a class="reference internal nav-link" href="{{ mpl_path('devel/index') }}">Contribute</a>
  </li>
  <li class="nav-item">
    <a class="reference internal nav-link" href="{{ mpl_path('users/release_notes') }}">Releases</a>
  </li>
</ul>
